test_templatetags Package
=========================

:mod:`test_permissionif` Module
-------------------------------

.. automodule:: permission.tests.test_templatetags.test_permissionif
    :members:
    :undoc-members:
    :show-inheritance:

